@@ -1,13 +1,12 @@
 //! Functions using all supported type patterns.
 
-use crate::patterns::result::FFIError;
-use crate::patterns::service::Error;
+use crate::patterns::result::{Error, FFIError};
 use crate::types::{
     ambiguous1, ambiguous2, common, some_foreign_type, Array, Callbacku8u8, Empty, EnumDocumented, EnumRenamedXYZ, Generic, Generic2, Generic3, Generic4, Opaque,
     Phantom, SomeForeignType, StructDocumented, StructRenamedXYZ, Tupled, Vec3f32, Visibility1, Visibility2, Weird1, Weird2,
 };
 use interoptopus::patterns::result::panics_and_errors_to_ffi_enum;
-use interoptopus::{ffi_function, here};
+use interoptopus::{ffi_function, ffi_surrogates, here};
 use std::ptr::null;
 use std::time::Duration;
 
@@ -146,7 +145,8 @@ pub extern "C" fn complex_args_1(_a: Vec3f32, _b: Option<&Empty>) -> FFIError {
     FFIError::Ok
 }
 
-#[ffi_function(unsafe, surrogates(_cmplx = "some_foreign_type"))]
+#[ffi_function]
+#[ffi_surrogates(_cmplx = "some_foreign_type")]
 #[no_mangle]
 pub extern "C" fn complex_args_2(_cmplx: SomeForeignType) -> *const Opaque {
     null()
