@@ -8,6 +8,12 @@ pub extern "C" fn pattern_ascii_pointer_1(x: AsciiPointer) -> u32 {
     x.as_c_str().map(|x| x.to_bytes().len()).unwrap_or(0) as u32
 }
 
+#[ffi_function]
+#[no_mangle]
+pub extern "C" fn pattern_ascii_pointer_2() -> AsciiPointer<'static> {
+    AsciiPointer::empty()
+}
+
 #[ffi_function]
 #[no_mangle]
 pub extern "C" fn pattern_ascii_pointer_len(x: AsciiPointer, y: UseAsciiStringPattern) -> u32 {
